@@ -31,20 +31,8 @@ class RecognizeBankCardRequest(RpcRequest):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
 
-	def get_ImageType(self):
-		return self.get_body_params().get('ImageType')
-
-	def set_ImageType(self,ImageType):
-		self.add_body_params('ImageType', ImageType)
-
 	def get_ImageURL(self):
 		return self.get_body_params().get('ImageURL')
 
 	def set_ImageURL(self,ImageURL):
-		self.add_body_params('ImageURL', ImageURL)
-
-	def get_ImageContent(self):
-		return self.get_body_params().get('ImageContent')
-
-	def set_ImageContent(self,ImageContent):
-		self.add_body_params('ImageContent', ImageContent)
\ No newline at end of file
+		self.add_body_params('ImageURL', ImageURL)
\ No newline at end of file
